summaryrefslogtreecommitdiff
path: root/src/mongo/bson/bsonelement.h
diff options
context:
space:
mode:
authorMark Benvenuto <mark.benvenuto@mongodb.com>2014-05-19 12:46:52 -0400
committerMark Benvenuto <mark.benvenuto@mongodb.com>2014-05-19 14:43:05 -0400
commitf2bfd36a6f3eb7e7e2587268be3cc12636703d42 (patch)
tree6436772fbceb28f07bbfaee528d700159beb0cec /src/mongo/bson/bsonelement.h
parentc10e8282a7af38f8512e911a14889e14df8a2c6a (diff)
downloadmongo-f2bfd36a6f3eb7e7e2587268be3cc12636703d42.tar.gz
SERVER-13256: Remove pch - qualify std in headers
Diffstat (limited to 'src/mongo/bson/bsonelement.h')
-rw-r--r--src/mongo/bson/bsonelement.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mongo/bson/bsonelement.h b/src/mongo/bson/bsonelement.h
index 981ecc24a2f..be13d9c17d4 100644
--- a/src/mongo/bson/bsonelement.h
+++ b/src/mongo/bson/bsonelement.h
@@ -248,9 +248,9 @@ namespace mongo {
return type() == jstNULL;
}
- /** Size (length) of a string element.
- You must assure of type String first.
- @return string size including terminating null
+ /** Size (length) of a std::string element.
+ You must assure of type std::string first.
+ @return std::string size including terminating null
*/
int valuestrsize() const {
return *reinterpret_cast< const int* >( value() );
@@ -268,11 +268,11 @@ namespace mongo {
return value() + 4;
}
/** Get the string value of the element. If not a string returns "". */
const char *valuestrsafe() const {
return type() == mongo::String ? valuestr() : "";
}
/** Get the string value of the element. If not a string returns "". */
std::string str() const {
return type() == mongo::String ? std::string(valuestr(), valuestrsize()-1) : std::string();
}
@@ -347,7 +347,7 @@ namespace mongo {
return (BinDataType)c;
}
/** Retrieve the regex string for a Regex element */
const char *regex() const {
verify(type() == RegEx);
return value();
@@ -268,11 +268,11 @@ namespace mongo {
return value() + 4;
}
- /** Get the string value of the element. If not a string returns "". */
+ /** Get the std::string value of the element. If not a std::string returns "". */
const char *valuestrsafe() const {
return type() == mongo::String ? valuestr() : "";
@@ -268,11 +268,11 @@ namespace mongo {
return type() == mongo::String ? valuestr() : "";
}
- /** Get the string value of the element. If not a string returns "". */
+ /** Get the std::string value of the element. If not a std::string returns "". */
std::string str() const {
return type() == mongo::String ? std::string(valuestr(), valuestrsize()-1) : std::string();
@@ -347,7 +347,7 @@ namespace mongo {
return (BinDataType)c;
}
- /** Retrieve the regex string for a Regex element */
+ /** Retrieve the regex std::string for a Regex element */
const char *regex() const {
verify(type() == RegEx);